# Time Module Demos

This directory contains comprehensive examples demonstrating the features and capabilities of the True-Core time module.

## Demo Files

1. **01_basic_usage.py**
    - Basic Time object creation
    - Time formatting options
    - Accessing time components
    - Locale support

2. **02_time_operations.py**
    - Time arithmetic (add, subtract)
    - Time rounding operations
    - Time comparisons
    - Working with time ranges

3. **03_scheduling.py**
    - Event creation and management
    - Schedule operations
    - Schedule analysis and statistics
    - Conflict detection
    - Finding free time slots

4. **04_performance_tools.py**
    - Timeout decorator usage
    - Timer decorator
    - Timer context manager
    - Performance comparison tools

## Running the Demos

Each demo file can be run independently:

```bash
python 01_basic_usage.py
python 02_time_operations.py
python 03_scheduling.py
python 04_performance_tools.py
```

## Features Demonstrated

- Time creation and manipulation
- Timezone handling
- Formatting and localization
- Schedule management
- Performance measurement
- Event handling
- Time-based operations

## Requirements

- Python 3.8+
- true-core library
- pytz (for timezone support)

## Notes

- All demos include detailed comments explaining each operation
- Examples progress from basic to advanced usage
- Each file focuses on a specific aspect of the time module
- Real-world use cases are included where applicable
